@@ -1,11 +1,15 @@
 # -*- coding: utf-8 -*-
 from typing import Any
 
-from starlette.responses import JSONResponse
-
 from jsonbourne import JSON
 
 
+try:
+    from starlette.responses import JSONResponse
+except ModuleNotFoundError:
+    JSONResponse = object
+
+
 class JSONBOURNEResponse(JSONResponse):
     """FastAPI/starlette json response to auto use jsonbourne"""
 
