@@ -1,15 +1,19 @@
 # -*- coding: utf-8 -*-
 import json
-from typing import Any
 
-from jsonbourne.jsonlib.base import JsonLib
-from jsonbourne.jsonlib.base import _json_encode_default
+from typing import Any, Callable, Optional
+
+from jsonbourne.jsonlib.base import JsonLib, _json_encode_default
 
 
 class JSON_STDLIB(JsonLib):
     @staticmethod
     def dumps(
-        data: Any, pretty: bool = False, sort_keys: bool = False, default=None, **kwargs
+        data: Any,
+        pretty: bool = False,
+        sort_keys: bool = False,
+        default: Optional[Callable[[Any], Any]] = None,
+        **kwargs: Any,
     ) -> str:
         separators = (",", ": ") if pretty else (",", ":")
         return json.dumps(
@@ -23,14 +27,22 @@ class JSON_STDLIB(JsonLib):
 
     @staticmethod
     def dumpb(
-        data: Any, pretty: bool = False, sort_keys: bool = False, default=None, **kwargs
-    ) -> str:
+        data: Any,
+        pretty: bool = False,
+        sort_keys: bool = False,
+        default: Optional[Callable[[Any], Any]] = None,
+        **kwargs: Any,
+    ) -> bytes:
         return JSON_STDLIB.dumps(
-            data, pretty=pretty, sort_keys=sort_keys, default=default, **kwargs
+            data,
+            pretty=pretty,
+            sort_keys=sort_keys,
+            default=default or _json_encode_default,
+            **kwargs,
         ).encode()
 
     @staticmethod
-    def loads(string: str, **kwargs) -> Any:
+    def loads(string: str, **kwargs: Any) -> Any:
         return json.loads(string, **kwargs)
 
 
