@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 """Json Bourne types"""
 import sys
-from typing import Any
-from typing import Dict
-from typing import List
+
+from typing import Any, Dict, List
+
 
 if sys.version_info < (3, 7):
     from collections.abc import MutableMapping
@@ -21,7 +21,6 @@ __all__ = [
     "JsonObjT",
 ]
 
-
 # Json friendly: Union[None, bool, int, float, str, List[Any], Dict[str, Any]]
 JsonDictT = Dict[str, Any]
 JsonObjT = Dict[str, Any]
